﻿using Hotline.Settings;
using Hotline.Share.Dtos.Knowledge;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Authentications;
using XF.Domain.Dependency;

namespace Hotline.KnowledgeBase
{
    public class KnowledgeService : IKnowledgeService, IScopeDependency
    {
        private readonly ISystemOrganizeRepository _systemOrganizeRepository;
        private readonly IOrgUserRepository _orgUserRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="_systemOrganizeRepository"></param>
        public KnowledgeService(ISystemOrganizeRepository systemOrganizeRepository, IOrgUserRepository orgUserRepository)
        {
            _systemOrganizeRepository = systemOrganizeRepository;
            _orgUserRepository = orgUserRepository;
        }

        /// <summary>
        /// 根据用户ID获取当前用户所属部门及下级部门Code
        /// </summary>
        /// <param name="userId"></param>
        /// <returns></returns>
        public async Task<List<string>> GetChildBMCode(string? userId)
        {
            var orgUser = await _orgUserRepository.GetAsync(p => p.UserId == userId);
            List<string> list = new();
            if (orgUser != null)
            {
                list.Add(orgUser.OrgCode);
                list.AddRange( await GetChildNode(orgUser.Id));
            }
            return list;
        }

        /// <summary>
        /// 查询下级部门
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
        private async Task<List<string>> GetChildNode(string Id)
        {
            List<string> list = new();
            var typelist = await _systemOrganizeRepository.QueryAsync(p => p.ParentId == Id);
            if (typelist != null)
            {
                foreach (var item in typelist)
                {
                    list.Add(item.OrgCode);
                    list.AddRange(await GetChildNode(item.Id));
                }
            }
            return list;
        }
    }
}

